require ( "config" )
require ( "prototypes/entities/enemies/spawner-animations" )
require ( "prototypes/entities/enemies/enemy-autoplace" )

local max_friends = 10

for k, faction in pairs( Robots ) do

	data:extend({

	  {
	   type = "autoplace-control",
	   name = faction.team,
	   richness = true,
	   order = "r-f"
	  },
	
	  {
	    type = "noise-layer",
	    name = faction.team
	  },
	  
	  {
		type = "unit-spawner",
		name = "small-robot-factory-"..faction.id,
		icon = "__base__/graphics/icons/biter-spawner.png",
		flags = {"placeable-player", "placeable-enemy"},
		max_health = 250,
		order="s-r-f",
		subgroup="enemies",
		loot = 
		{
			{ item = "iron-plate", probability = 1, count_min = 1, count_max = 10 },
			{ item = "copper-plate", probability = 1, count_min = 1, count_max = 8 },
			{ item = "steel-plate", probability = 1, count_min = 1, count_max = 5 },
			{ item = "electronic-circuit", probability = 0.9, count_min = 1, count_max = 4 },
			{ item = "iron-gear-wheel", probability = 0.75, count_min = 1, count_max = 3 },
			{ item = "copper-cable", probability = 0.5, count_min = 1, count_max = 2 },
		},
		resistances =
		{
		  {
			type = "laser",
			decrease = 2,
			percent = 15
		  },	  
		  {
			type = "impact",
			decrease = 10,
			percent = 30
		  },
		  {
			type = "physical",
			decrease = 4,
			percent = 15
		  },
		  {
			type = "explosion",
			decrease = 4,
			percent = 15,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 40,
		  },		  
		  {
			type = "electric",
			decrease = 2,
			percent = 10,
		  },
		},
		working_sound =
		{
		  sound = {
			{
			  filename = "__base__/sound/assembling-machine-t3-1.ogg",
			  volume = 0.8
			},
			{
			  filename = "__base__/sound/assembling-machine-t3-2.ogg",
			  volume = 0.8
			},
		  },
		},
		dying_sound =
		{
		  {
			filename = "__ManVersusMachine__/sound/factory-explode.ogg",
			volume = 0.75
		  },
		},
		healing_per_tick = 0,
		collision_box = {{-2, -2}, {2, 2}},
		selection_box = {{-2.1, -2.1}, {2.1, 2.1}},
		-- in ticks per 1 pu
		pollution_absorbtion_absolute = 0,
		pollution_absorbtion_proportional = 0,
		corpse = "big-remnants",
		dying_explosion = "medium-explosion",
		max_count_of_owned_units = 8,
		max_friends_around_to_spawn = max_friends,
		animations =
		{
		  small_robot_factory_idle_animation(faction.color)
		},
		result_units = (function()
						 local res = {}
						 res[1] = {"small-pistol-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[2] = {"small-machine-gun-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[3] = {"small-shotgun-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[4] = {"small-flame-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[5] = {"small-rocket-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[6] = {"small-grenade-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[7] = {"small-tesla-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[8] = {"small-laser-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						   -- from evolution_factor 0.3 the weight for medium-biter is linearly rising from 0 to 0.3
						   -- this means for example that when the evolution_factor is 0.45 the probability of spawning
						   -- a small biter is 66% while probability for medium biter is 33%.
						 --res[2] = {"medium-biter", {{0.2, 0.0}, {0.6, 0.3}, {0.7, 0.1}}}
						   -- for evolution factor of 1 the spawning probabilities are: small-biter 0%, medium-biter 1/8, big-biter 4/8, behemoth biter 3/8
						 --res[3] = {"big-biter", {{0.5, 0.0}, {1.0, 0.4}}}
						 --res[4] = {"behemoth-biter", {{0.9, 0.0}, {1.0, 0.3}}}
						 return res
					   end)(),
		-- With zero evolution the spawn rate is 6 seconds, with max evolution it is 2.5 seconds
		spawning_cooldown = {300, 300},
		spawning_radius = 10,
		spawning_spacing = 3,
		max_spawn_shift = 0,
		max_richness_for_spawn_shift = 100,
		autoplace = faction_spawner_autoplace( {
			distance = 0,
			is_turret = false,
			team = faction.team,
			spawning_penalty = faction.spawning_penalty,
			random_probability_penalty = ( 0.2 * faction.random_probability_penalty_percent ) ,
		} ),
		map_color = faction.color,
		call_for_help_radius = 50
	  },
	  
	  {
		type = "unit-spawner",
		name = "medium-robot-factory-"..faction.id,
		icon = "__base__/graphics/icons/biter-spawner.png",
		flags = {"placeable-player", "placeable-enemy"},
		max_health = 500,
		order="m-r-f",
		subgroup="enemies",
		loot = 
		{
			{ item = "iron-plate", probability = 1, count_min = 1, count_max = 20 },
			{ item = "copper-plate", probability = 1, count_min = 1, count_max = 18 },
			{ item = "steel-plate", probability = 1, count_min = 1, count_max = 10 },
			{ item = "electronic-circuit", probability = 0.95, count_min = 1, count_max = 8 },
			{ item = "iron-gear-wheel", probability = 0.9, count_min = 1, count_max = 8 },
			{ item = "copper-cable", probability = 0.85, count_min = 1, count_max = 8 },
			{ item = "advanced-circuit", probability = 0.7, count_min = 1, count_max = 4 },
			{ item = "plastic-bar", probability = 0.6, count_min = 1, count_max = 6 },
			{ item = "sulfur", probability = 0.5, count_min = 1, count_max = 6 },
			{ item = "engine-unit", probability = 0.35, count_min = 1, count_max = 2 },
		},
		resistances =
		{
		  {
			type = "laser",
			decrease = 4,
			percent = 30
		  },	  
		  {
			type = "impact",
			decrease = 12,
			percent = 35
		  },
		  {
			type = "physical",
			decrease = 8,
			percent = 30
		  },
		  {
			type = "explosion",
			decrease = 6,
			percent = 30,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 60,
		  },		  
		  {
			type = "electric",
			decrease = 8,
			percent = 15,
		  },
		},
		working_sound =
		{
		  sound = {
			{
			  filename = "__base__/sound/assembling-machine-t3-1.ogg",
			  volume = 0.9
			},
			{
			  filename = "__base__/sound/assembling-machine-t3-2.ogg",
			  volume = 0.9
			},
		  },
		},
		dying_sound =
		{
		  {
			filename = "__ManVersusMachine__/sound/factory-explode.ogg",
			volume = 1
		  },
		},
		healing_per_tick = 0,
		collision_box = {{-3, -3}, {3, 3}},
		selection_box = {{-3.1, -3.1}, {3.1, 3.1}},
		-- in ticks per 1 pu
		pollution_absorbtion_absolute = 0,
		pollution_absorbtion_proportional = 0,
		corpse = "big-remnants",
		dying_explosion = "medium-explosion",
		max_count_of_owned_units = 6,
		max_friends_around_to_spawn = max_friends,
		animations =
		{
		  medium_robot_factory_idle_animation(faction.color)
		},
		result_units = (function()
						 local res = {}
						 res[1] = {"medium-pistol-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[2] = {"medium-machine-gun-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[3] = {"medium-shotgun-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[4] = {"medium-flame-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[5] = {"medium-rocket-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[6] = {"medium-grenade-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[7] = {"medium-tesla-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[8] = {"medium-laser-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 return res
					   end)(),
		spawning_cooldown = {600, 600},
		spawning_radius = 10,
		spawning_spacing = 3,
		max_spawn_shift = 0,
		max_richness_for_spawn_shift = 100,
		autoplace = faction_spawner_autoplace( {
			distance = 2,
			is_turret = false,
			team = faction.team,
			spawning_penalty = faction.spawning_penalty,
			random_probability_penalty = ( 0.2 * faction.random_probability_penalty_percent ) ,
		} ),
		map_color = faction.color,
		call_for_help_radius = 50
	  },
	  
	  {
		type = "unit-spawner",
		name = "large-robot-factory-"..faction.id,
		icon = "__base__/graphics/icons/biter-spawner.png",
		flags = {"placeable-player", "placeable-enemy"},
		max_health = 1000,
		order="l-r-f",
		subgroup="enemies",
		loot = 
		{
			{ item = "iron-plate", probability = 1, count_min = 1, count_max = 40 },
			{ item = "copper-plate", probability = 1, count_min = 1, count_max = 38 },
			{ item = "steel-plate", probability = 1, count_min = 1, count_max = 25 },
			{ item = "electronic-circuit", probability = 0.95, count_min = 1, count_max = 30 },
			{ item = "iron-gear-wheel", probability = 0.9, count_min = 1, count_max = 25 },
			{ item = "copper-cable", probability = 0.9, count_min = 1, count_max = 30 },
			{ item = "advanced-circuit", probability = 0.8, count_min = 1, count_max = 20 },
			{ item = "plastic-bar", probability = 0.75, count_min = 1, count_max = 15 },
			{ item = "sulfur", probability = 0.6, count_min = 1, count_max = 10 },
			{ item = "processing-unit", probability = 0.5, count_min = 1, count_max = 6 },
			{ item = "explosives", probability = 0.45, count_min = 1, count_max = 4 },
			{ item = "engine-unit", probability = 0.4, count_min = 1, count_max = 4 },
			{ item = "electric-engine-unit", probability = 0.35, count_min = 1, count_max = 2 },
		},
		resistances =
		{
		  {
			type = "laser",
			decrease = 5,
			percent = 40
		  },	  
		  {
			type = "impact",
			decrease = 15,
			percent = 50
		  },
		  {
			type = "physical",
			decrease = 10,
			percent = 35
		  },
		  {
			type = "explosion",
			decrease = 8,
			percent = 35,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 80,
		  },		  
		  {
			type = "electric",
			decrease = 10,
			percent = 20,
		  },
		},
		working_sound =
		{
		  sound = {
			{
			  filename = "__base__/sound/assembling-machine-t3-1.ogg",
			  volume = 1
			},
			{
			  filename = "__base__/sound/assembling-machine-t3-2.ogg",
			  volume = 1
			},
		  },
		},
		dying_sound =
		{
		  {
			filename = "__ManVersusMachine__/sound/factory-explode.ogg",
			volume = 1.25
		  },
		},
		healing_per_tick = 0,
		collision_box = {{-3.75, -3.75}, {3.75, 3.75}},
		selection_box = {{-3.8, -3.8}, {3.8, 3.8}},
		-- in ticks per 1 pu
		pollution_absorbtion_absolute = 0,
		pollution_absorbtion_proportional = 0,
		corpse = "big-remnants",
		dying_explosion = "medium-explosion",
		max_count_of_owned_units = 4,
		max_friends_around_to_spawn = max_friends,
		animations =
		{
		  large_robot_factory_idle_animation(faction.color)
		},
		result_units = (function()
						 local res = {}
						 res[1] = {"large-pistol-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[2] = {"large-machine-gun-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[3] = {"large-shotgun-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[4] = {"large-flame-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[5] = {"large-rocket-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[6] = {"large-grenade-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[7] = {"large-tesla-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[8] = {"large-laser-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 return res
					   end)(),
		spawning_cooldown = {1200, 1200},
		spawning_radius = 10,
		spawning_spacing = 3,
		max_spawn_shift = 0,
		max_richness_for_spawn_shift = 100,
		autoplace = faction_spawner_autoplace( {
			distance = 4,
			is_turret = false,
			team = faction.team,
			spawning_penalty = faction.spawning_penalty,
			random_probability_penalty = ( 0.2 * faction.random_probability_penalty_percent ),
		} ),
		map_color = faction.color,
		call_for_help_radius = 50
	  },	  
	  
	  {
		type = "unit-spawner",
		name = "giant-robot-factory-"..faction.id,
		icon = "__base__/graphics/icons/biter-spawner.png",
		flags = {"placeable-player", "placeable-enemy"},
		max_health = 2000,
		order="g-r-f",
		subgroup="enemies",
		loot = 
		{
			{ item = "iron-plate", probability = 1, count_min = 1, count_max = 50 },
			{ item = "copper-plate", probability = 1, count_min = 1, count_max = 40 },
			{ item = "steel-plate", probability = 1, count_min = 1, count_max = 35 },
			{ item = "electronic-circuit", probability = 0.95, count_min = 1, count_max = 35 },
			{ item = "iron-gear-wheel", probability = 0.9, count_min = 1, count_max = 35 },
			{ item = "copper-cable", probability = 0.9, count_min = 1, count_max = 35 },
			{ item = "advanced-circuit", probability = 0.8, count_min = 1, count_max = 30 },
			{ item = "plastic-bar", probability = 0.75, count_min = 1, count_max = 25 },
			{ item = "sulfur", probability = 0.7, count_min = 1, count_max = 25 },
			{ item = "processing-unit", probability = 0.6, count_min = 1, count_max = 20 },
			{ item = "explosives", probability = 0.5, count_min = 1, count_max = 10 },
			{ item = "battery", probability = 0.5, count_min = 1, count_max = 8 },
			{ item = "engine-unit", probability = 0.5, count_min = 1, count_max = 5 },
			{ item = "electric-engine-unit", probability = 0.5, count_min = 1, count_max = 4 },
			{ item = "uranium-235", probability = 0.1, count_min = 1, count_max = 2 },
			{ item = "uranium-238", probability = 0.45, count_min = 1, count_max = 10 },
		},
		resistances =
		{
		  {
			type = "laser",
			decrease = 10,
			percent = 60
		  },	  
		  {
			type = "impact",
			decrease = 20,
			percent = 75
		  },
		  {
			type = "physical",
			decrease = 15,
			percent = 50
		  },
		  {
			type = "explosion",
			decrease = 10,
			percent = 45,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 90,
		  },		  
		  {
			type = "electric",
			decrease = 15,
			percent = 25,
		  },
		},
		working_sound =
		{
		  sound = {
			{
			  filename = "__base__/sound/assembling-machine-t3-1.ogg",
			  volume = 1.1
			},
			{
			  filename = "__base__/sound/assembling-machine-t3-2.ogg",
			  volume = 1.1
			},
		  },
		},
		dying_sound =
		{
		  {
			filename = "__ManVersusMachine__/sound/factory-explode.ogg",
			volume = 1.5
		  },
		},
		healing_per_tick = 0,
		collision_box = {{-4.75, -4.75}, {4.75, 4.75}},
		selection_box = {{-4.8, -4.8}, {4.8, 4.8}},
		-- in ticks per 1 pu
		pollution_absorbtion_absolute = 0,
		pollution_absorbtion_proportional = 0,
		corpse = "big-remnants",
		dying_explosion = "medium-explosion",
		max_count_of_owned_units = 2,
		max_friends_around_to_spawn = max_friends,
		animations =
		{
		  giant_robot_factory_idle_animation(faction.color)
		},
		result_units = (function()
						 local res = {}
						 res[1] = {"giant-pistol-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[2] = {"giant-machine-gun-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[3] = {"giant-shotgun-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[4] = {"giant-flame-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[5] = {"giant-rocket-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[6] = {"giant-grenade-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[7] = {"giant-tesla-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 res[8] = {"giant-laser-bot-"..faction.id, {{0.0, 1}, {1, 1}}}
						 return res
					   end)(),
		spawning_cooldown = {3600, 3600},
		spawning_radius = 10,
		spawning_spacing = 3,
		max_spawn_shift = 0,
		max_richness_for_spawn_shift = 100,
		autoplace = faction_spawner_autoplace( {
			distance = 6,
			is_turret = false,
			team = faction.team,
			spawning_penalty = faction.spawning_penalty,
			random_probability_penalty = ( 0.2 * faction.random_probability_penalty_percent ),
		} ),
		map_color = faction.color,
		call_for_help_radius = 50
	  },
	  
	})

end
