require ( "config" )
require ( "prototypes/entities/enemies/unit-animations" )
require ( "prototypes/entities/enemies/unit-sounds" )

function bullet_attack_parameters(data)
  return
  {
    type = "projectile",
    ammo_category = "bullet",
    cooldown = data.cooldown,
    range = data.range,
    min_attack_distance = data.min_attack_distance,
    projectile_creation_distance = data.projectile_creation_distance,
    damage_modifier = data.damage_modifier,
    warmup = data.warmup,
    ammo_type =
    {
      category = "biological",
      action =
      {
        type = "direct",
        action_delivery =
        {
          type = "instant",
          source_effects =
          {
            type = "create-explosion",
            entity_name = "explosion-gunshot"
          },
          target_effects =
          {
            {
              type = "create-entity",
              entity_name = "explosion-hit"
            },
            {
              type = "damage",
              damage = { amount = data.damage_amount, type = data.damage_type }
            }
          }
        }
      }
    },
    sound = data.sound,
    animation = data.animation,
  }
end

function rocket_attack_parameters(data)
  return
  {
    type = "projectile",
    ammo_category = "rocket",
    cooldown = data.cooldown,
    range = data.range,
    min_attack_distance = data.min_attack_distance,
    projectile_creation_distance = data.projectile_creation_distance,
    damage_modifier = ( data.damage_modifier ) * ( data.damage_amount ),
    warmup = data.warmup,
    ammo_type =
    {
      category = "rocket",
      action =
      {
        type = "direct",
        action_delivery =
        {
          type = "projectile",
          projectile = "rocket",
          starting_speed = 0.5,
          max_range = data.range*2
        }
      }
    },
    sound = data.sound,
    animation = data.animation,
  }
end

function grenade_attack_parameters(data)
  return
  {
    type = "projectile",
    ammo_category = "rocket",
    cooldown = data.cooldown,
    range = data.range,
    min_attack_distance = data.min_attack_distance,
    projectile_creation_distance = data.projectile_creation_distance,
    damage_modifier = ( data.damage_modifier ) * ( data.damage_amount ),
    warmup = data.warmup,
    ammo_type =
	{
	  category = "grenade",
	  target_type = "position",
	  action =
	  {
		type = "direct",
		action_delivery =
		{
		  type = "projectile",
		  projectile = "grenade",
		  starting_speed = 0.3
		}
	  }
	},
    sound = data.sound,
    animation = data.animation,
  }
end

function pellet_attack_parameters(data)
  return
  {
    type = "projectile",
    ammo_category = "rocket",
    cooldown = data.cooldown,
    range = data.range,
    min_attack_distance = data.min_attack_distance,
    projectile_creation_distance = data.projectile_creation_distance,
    damage_modifier = ( data.damage_modifier ) * ( data.damage_amount ),
    warmup = data.warmup,
    ammo_type =
    {
      category = "shotgun-shell",
      target_type = "direction",
      action =
      {
        {
          type = "direct",
          action_delivery =
          {
            type = "instant",
            source_effects =
            {
              {
                type = "create-explosion",
                entity_name = "explosion-gunshot"
              }
            }
          }
        },
        {
          type = "direct",
          repeat_count = data.repeat_count,
          action_delivery =
          {
            type = "projectile",
            projectile = "shotgun-pellet",
            starting_speed = 1,
            direction_deviation = 0.3,
            range_deviation = 0.3,
            max_range = 15
          }
        }
      }
    },
    sound = data.sound,
    animation = data.animation,
  }
end

function laser_attack_parameters(data)
  return
  {
	type = "projectile",
	ammo_category = "electric",
	cooldown = data.cooldown,
	projectile_center = {-0.09375, -0.2},
	projectile_creation_distance = data.projectile_creation_distance,
	range = data.range,
	damage_modifier = data.damage_modifier,
	ammo_type =
	{
	type = "projectile",
	category = "laser-turret",
	action =
	{
	  {
		type = "direct",
		action_delivery =
		{
		  {
			type = "projectile",
			projectile = "laser",
			starting_speed = 0.35
		  }
		}
	  }
	}
	},
    sound = data.sound,
    animation = data.animation,
  }
end

function beam_attack_parameters(data)
  return
	{
	  type = "beam",
	  ammo_category = "combat-robot-beam",
	  cooldown = data.cooldown,
	  projectile_creation_distance = data.projectile_creation_distance,
	  range = data.range,
	  damage_modifier = ( data.damage_modifier ) * ( data.damage_amount ),
	  sound = data.sound,
	  animation = data.animation,
	  ammo_type =
	  {
		category = "combat-robot-beam",
		action =
		{
		  type = "direct",
		  action_delivery =
		  {
			type = "beam",
			beam = "electric-beam",
			max_length = data.max_length,
			duration = data.duration,
			source_offset = {0.15, -0.5},
		  }
		}
	  }
	}
end

function flame_attack_parameters(data)
  return
  {
      type = "stream",
      ammo_category = "flamethrower",
      cooldown = data.cooldown,
	  warmup = data.warmup,
      projectile_creation_distance = data.projectile_creation_distance,
      gun_barrel_length = 1.4,
      gun_center_shift = { -0.17, -1.15 },
      range = data.range,
	  min_attack_distance = data.min_attack_distance,
	  animation = data.animation,
	  --sound = data.sound,
      min_range = ( data.range - 1 ),
	  damage_modifier = ( data.damage_modifier ) * ( data.damage_amount ),
      cyclic_sound =
      {
        begin_sound =
        {
          {
            filename = "__base__/sound/fight/flamethrower-start.ogg",
            volume = data.sound_volume
          }
        },
        middle_sound =
        {
          {
            filename = "__base__/sound/fight/flamethrower-mid.ogg",
            volume = data.sound_volume
          }
        },
        end_sound =
        {
          {
            filename = "__base__/sound/fight/flamethrower-end.ogg",
            volume = data.sound_volume
          }
        }
      },
	  ammo_type =
      {
			category = "flamethrower",
			target_type = "position",
			clamp_position = true,
			action =
			{
			  type = "direct",
			  action_delivery =
			  {
				type = "stream",
				stream = "tank-flamethrower-fire-stream",
				max_length = 15,
				duration = 160,
			  }
			},
	  },
  }
end

scale_small_bot = 0.5
scale_medium_bot = 0.75
scale_large_bot = 1
scale_giant_bot = 1.5

projectile_creation_distance_small_bot = 1.5
projectile_creation_distance_medium_bot = 2
projectile_creation_distance_large_bot = 2.5
projectile_creation_distance_giant_bot = 3.5

speed_small_bot = 0.1
speed_medium_bot = 0.08
speed_large_bot = 0.06
speed_giant_bot = 0.04

for k, faction in pairs ( Robots ) do

	data:extend({	 

	  {
		type = "unit",
		name = "small-pistol-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 20,
		order = "p-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 5
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 5,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 5,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 5,
		  },
		},
		collision_box = {{-0.2, -0.2}, {0.2, 0.2}},
		selection_box = {{-0.4, -0.7}, {0.7, 0.4}},
		attack_parameters = bullet_attack_parameters(
		{
		  range = 8,
		  min_attack_distance = 7,
		  projectile_creation_distance = projectile_creation_distance_small_bot,
		  warmup = 1,
		  cooldown = 45,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 2,
		  damage_type = "physical",
		  sound = light_gunshots(0.4),
		  animation = bot_attack_animation( scale_small_bot, faction.color, "pistol" )
		}),
		vision_distance = 30,
		movement_speed = speed_small_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "small-remnants",
		--dying_explosion = "small-explosion",
		dying_sound = robot_dying_sounds( 0.4 ),
		working_sound = robot_working_sounds( 0.75, "1" ),
		run_animation = bot_run_animation( scale_small_bot, faction.color, "pistol" )
	  },	  
	  
	  {
		type = "unit",
		name = "small-machine-gun-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 30,
		order = "m-g-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 5
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "physical",
			decrease = 1,
			percent = 10
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 5,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 5,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 5,
		  },
		},
		collision_box = {{-0.2, -0.2}, {0.2, 0.2}},
		selection_box = {{-0.4, -0.7}, {0.7, 0.4}},
		attack_parameters = bullet_attack_parameters(
		{
		  range = 10,
		  min_attack_distance = 9,
		  projectile_creation_distance = projectile_creation_distance_small_bot,
		  warmup = 1,
		  cooldown = 12,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 2,
		  damage_type = "physical",
		  sound = light_gunshots(0.55),
		  animation = bot_attack_animation( scale_small_bot, faction.color, "machine-gun" )
		}),
		vision_distance = 32,
		movement_speed = speed_small_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "small-remnants",
		--dying_explosion = "small-explosion",
		dying_sound = robot_dying_sounds( 0.4 ),
		working_sound = robot_working_sounds( 0.75, "1" ),
		run_animation = bot_run_animation( scale_small_bot, faction.color, "machine-gun" )
	  },

	  {
		type = "unit",
		name = "small-shotgun-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 40,
		order = "s-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 5
		  },	  
		  {
			type = "impact",
			decrease = 1,
			percent = 10
		  },
		  {
			type = "physical",
			decrease = 1,
			percent = 5
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 5,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 5,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 5,
		  },
		},
		collision_box = {{-0.2, -0.2}, {0.2, 0.2}},
		selection_box = {{-0.4, -0.7}, {0.7, 0.4}},
		attack_parameters = pellet_attack_parameters(
		{
		  range = 9,
		  min_attack_distance = 8,
		  projectile_creation_distance = projectile_creation_distance_small_bot,
		  warmup = 1,
		  cooldown = 90,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.2 * 2,
		  repeat_count = 6,
		  sound = shotgun_shots(0.55),
		  animation = bot_attack_animation( scale_small_bot, faction.color, "shotgun" )
		}),
		vision_distance = 30,
		movement_speed = speed_small_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "small-remnants",
		--dying_explosion = "small-explosion",
		dying_sound = robot_dying_sounds( 0.4 ),
		working_sound = robot_working_sounds( 0.75, "1" ),
		run_animation = bot_run_animation( scale_small_bot, faction.color, "shotgun" )
	  },
	  
	  {
		type = "unit",
		name = "small-flame-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 50,
		order = "f-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 5
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 5,
		  },
		  {
			type = "fire",
			decrease = 1,
			percent = 60,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 5,
		  },
		},
		collision_box = {{-0.2, -0.2}, {0.2, 0.2}},
		selection_box = {{-0.4, -0.7}, {0.7, 0.4}},
		attack_parameters = flame_attack_parameters(
		{
		  range = 10,
		  min_attack_distance = 9,
		  projectile_creation_distance = projectile_creation_distance_small_bot,
		  warmup = 1,
		  cooldown = 2,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.14 * 0.5,
		  sound_volume = 0.6,
		  animation = bot_attack_animation( scale_small_bot, faction.color, "flame" )
		}),
		vision_distance = 34,
		movement_speed = speed_small_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "small-remnants",
		--dying_explosion = "small-explosion",
		dying_sound = robot_dying_sounds( 0.4 ),
		working_sound = robot_working_sounds( 0.75, "2" ),
		run_animation = bot_run_animation( scale_small_bot, faction.color, "flame" )
	  },	
	  
	  {
		type = "unit",
		name = "small-rocket-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 60,
		order = "r-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 5
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "explosion",
			decrease = 5,
			percent = 15,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 5,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 5,
		  },
		},
		collision_box = {{-0.2, -0.2}, {0.2, 0.2}},
		selection_box = {{-0.4, -0.7}, {0.7, 0.4}},
		attack_parameters = rocket_attack_parameters(
		{
		  range = 12,
		  min_attack_distance = 11,
		  projectile_creation_distance = projectile_creation_distance_small_bot,
		  warmup = 30,
		  cooldown = 180,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.005 * 10,
		  sound = rocket_shots(0.55),
		  animation = bot_attack_animation( scale_small_bot, faction.color, "rocket" )
		}),
		vision_distance = 35,
		movement_speed = speed_small_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "small-remnants",
		--dying_explosion = "small-explosion",
		dying_sound = robot_dying_sounds( 0.4 ),
		working_sound = robot_working_sounds( 0.75, "2" ),
		run_animation = bot_run_animation( scale_small_bot, faction.color, "rocket" )
	  },		 

	  {
		type = "unit",
		name = "small-grenade-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 70,
		order = "g-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 5
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "explosion",
			decrease = 5,
			percent = 15,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 5,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 5,
		  },
		},
		collision_box = {{-0.2, -0.2}, {0.2, 0.2}},
		selection_box = {{-0.4, -0.7}, {0.7, 0.4}},
		attack_parameters = grenade_attack_parameters(
		{
		  range = 12,
		  min_attack_distance = 11,
		  projectile_creation_distance = projectile_creation_distance_small_bot,
		  warmup = 45,
		  cooldown = 210,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.0285 * 5,
		  sound = grenade_shots(0.55),
		  animation = bot_attack_animation( scale_small_bot, faction.color, "grenade" )
		}),
		vision_distance = 35,
		movement_speed = speed_small_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "small-remnants",
		--dying_explosion = "small-explosion",
		dying_sound = robot_dying_sounds( 0.4 ),
		working_sound = robot_working_sounds( 0.75, "2" ),
		run_animation = bot_run_animation( scale_small_bot, faction.color, "grenade" )
	  },		  
	  
	  {
		type = "unit",
		name = "small-tesla-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 75,
		order = "t-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 5
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 5,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 5,
		  },		  
		  {
			type = "electric",
			decrease = 1,
			percent = 10,
		  },
		},
		collision_box = {{-0.2, -0.2}, {0.2, 0.2}},
		selection_box = {{-0.4, -0.7}, {0.7, 0.4}},
		attack_parameters = beam_attack_parameters(
		{
		  range = 11,
		  min_attack_distance = 10,
		  projectile_creation_distance = projectile_creation_distance_small_bot,
		  warmup = 0,
		  cooldown = 20,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.1 * 2,
		  sound = beam_shots(1),
		  max_length = 12,
		  duration = 20,
		  animation = bot_attack_animation( scale_small_bot, faction.color, "tesla" )
		}),
		vision_distance = 35,
		movement_speed = speed_small_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "small-remnants",
		--dying_explosion = "small-explosion",
		dying_sound = robot_dying_sounds( 0.4 ),
		working_sound = robot_working_sounds( 0.75, "2" ),
		run_animation = bot_run_animation( scale_small_bot, faction.color, "tesla" )
	  },		  
	  
	  {
		type = "unit",
		name = "small-laser-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 80,
		order = "l-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 2,
			percent = 10
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 5
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 5,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 5,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 5,
		  },
		},
		collision_box = {{-0.2, -0.2}, {0.2, 0.2}},
		selection_box = {{-0.4, -0.7}, {0.7, 0.4}},
		attack_parameters = laser_attack_parameters(
		{
		  range = 13,
		  min_attack_distance = 12,
		  projectile_creation_distance = projectile_creation_distance_small_bot + 0.5,
		  warmup = 1,
		  cooldown = 60,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.2 * 2,
		  sound = laser_shots(0.55),
		  animation = bot_attack_animation( scale_small_bot, faction.color, "laser" )
		}),
		vision_distance = 35,
		movement_speed = speed_small_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "small-remnants",
		--dying_explosion = "small-explosion",
		dying_sound = robot_dying_sounds( 0.4 ),
		working_sound = robot_working_sounds( 0.75, "2" ),
		run_animation = bot_run_animation( scale_small_bot, faction.color, "laser" )
	  },	
	  ----------------------------------------------------------------------------------------------------------------------------------------
	  {
		type = "unit",
		name = "medium-pistol-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 100,
		order = "p-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 10
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 10,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 10,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 10,
		  },
		},
		collision_box = {{-0.3, -0.3}, {0.3, 0.3}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = bullet_attack_parameters(
		{
		  range = 9,
		  min_attack_distance = 8,
		  projectile_creation_distance = projectile_creation_distance_medium_bot,
		  warmup = 1,
		  cooldown = 30,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 4,
		  damage_type = "physical",
		  sound = light_gunshots(0.5),
		  animation = bot_attack_animation( scale_medium_bot, faction.color, "pistol" )
		}),
		vision_distance = 32,
		movement_speed = speed_medium_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = robot_dying_sounds( 0.6 ),
		working_sound = robot_working_sounds( 0.8, "3" ),
		run_animation = bot_run_animation( scale_medium_bot, faction.color, "pistol" )
	  },	  
	  
	  {
		type = "unit",
		name = "medium-machine-gun-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 120,
		order = "m-g-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 10
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "physical",
			decrease = 2,
			percent = 15
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 10,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 10,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 10,
		  },
		},
		collision_box = {{-0.3, -0.3}, {0.3, 0.3}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = bullet_attack_parameters(
		{
		  range = 11,
		  min_attack_distance = 10,
		  projectile_creation_distance = projectile_creation_distance_medium_bot,
		  warmup = 1,
		  cooldown = 6,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 4,
		  damage_type = "physical",
		  sound = light_gunshots(0.5),
		  animation = bot_attack_animation( scale_medium_bot, faction.color, "machine-gun" )
		}),
		vision_distance = 33,
		movement_speed = speed_medium_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = robot_dying_sounds( 0.6 ),
		working_sound = robot_working_sounds( 0.8, "3" ),
		run_animation = bot_run_animation( scale_medium_bot, faction.color, "machine-gun" )
	  },

	  {
		type = "unit",
		name = "medium-shotgun-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 140,
		order = "s-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 10
		  },	  
		  {
			type = "impact",
			decrease = 4,
			percent = 15
		  },
		  {
			type = "physical",
			decrease = 2,
			percent = 10
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 10,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 10,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 10,
		  },
		},
		collision_box = {{-0.3, -0.3}, {0.3, 0.3}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = pellet_attack_parameters(
		{
		  range = 10,
		  min_attack_distance = 9,
		  projectile_creation_distance = projectile_creation_distance_medium_bot,
		  warmup = 1,
		  cooldown = 60,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.2 * 4,
		  repeat_count = 8,
		  sound = shotgun_shots(0.65),
		  animation = bot_attack_animation( scale_medium_bot, faction.color, "shotgun" )
		}),
		vision_distance = 32,
		movement_speed = speed_medium_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = robot_dying_sounds( 0.6 ),
		working_sound = robot_working_sounds( 0.8, "3" ),
		run_animation = bot_run_animation( scale_medium_bot, faction.color, "shotgun" )
	  },
	  
	  {
		type = "unit",
		name = "medium-flame-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 160,
		order = "f-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 10
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 10,
		  },
		  {
			type = "fire",
			decrease = 2,
			percent = 75,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 10,
		  },
		},
		collision_box = {{-0.3, -0.3}, {0.3, 0.3}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = flame_attack_parameters(
		{
		  range = 11,
		  min_attack_distance = 10,
		  projectile_creation_distance = projectile_creation_distance_medium_bot,
		  warmup = 1,
		  cooldown = 2,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.14 * 1,
		  sound_volume = 0.7,
		  animation = bot_attack_animation( scale_medium_bot, faction.color, "flame" )
		}),
		vision_distance = 35,
		movement_speed = speed_medium_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = robot_dying_sounds( 0.6 ),
		working_sound = robot_working_sounds( 0.8, "3" ),
		run_animation = bot_run_animation( scale_medium_bot, faction.color, "flame" )
	  },	
	  
	  {
		type = "unit",
		name = "medium-rocket-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 200,
		order = "r-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 10
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "explosion",
			decrease = 10,
			percent = 20,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 10,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 10,
		  },
		},
		collision_box = {{-0.3, -0.3}, {0.3, 0.3}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = rocket_attack_parameters(
		{
		  range = 13,
		  min_attack_distance = 12,
		  projectile_creation_distance = projectile_creation_distance_medium_bot,
		  warmup = 20,
		  cooldown = 120,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.005 * 25,
		  sound = rocket_shots(0.65),
		  animation = bot_attack_animation( scale_medium_bot, faction.color, "rocket" )
		}),
		vision_distance = 36,
		movement_speed = speed_medium_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = robot_dying_sounds( 0.6 ),
		working_sound = robot_working_sounds( 0.8, "3" ),
		run_animation = bot_run_animation( scale_medium_bot, faction.color, "rocket" )
	  },
	  
	  {
		type = "unit",
		name = "medium-grenade-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 240,
		order = "g -b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 10
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "explosion",
			decrease = 10,
			percent = 25,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 10,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 10,
		  },
		},
		collision_box = {{-0.3, -0.3}, {0.3, 0.3}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = grenade_attack_parameters(
		{
		  range = 13,
		  min_attack_distance = 12,
		  projectile_creation_distance = projectile_creation_distance_medium_bot,
		  warmup = 30,
		  cooldown = 150,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.0285 * 15,
		  sound = grenade_shots(0.6),
		  animation = bot_attack_animation( scale_medium_bot, faction.color, "grenade" )
		}),
		vision_distance = 35,
		movement_speed = speed_medium_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = robot_dying_sounds( 0.6 ),
		working_sound = robot_working_sounds( 0.8, "3" ),
		run_animation = bot_run_animation( scale_medium_bot, faction.color, "grenade" )
	  },		  
	  
	  {
		type = "unit",
		name = "medium-tesla-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 250,
		order = "t-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 10
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 10,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 10,
		  },		  
		  {
			type = "electric",
			decrease = 4,
			percent = 20,
		  },
		},
		collision_box = {{-0.2, -0.2}, {0.2, 0.2}},
		selection_box = {{-0.4, -0.7}, {0.7, 0.4}},
		attack_parameters = beam_attack_parameters(
		{
		  range = 12,
		  min_attack_distance = 11,
		  projectile_creation_distance = projectile_creation_distance_small_bot,
		  warmup = 0,
		  cooldown = 20,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.1 * 8,
		  sound = beam_shots(1),
		  max_length = 13,
		  duration = 20,
		  animation = bot_attack_animation( scale_medium_bot, faction.color, "tesla" )
		}),
		vision_distance = 36,
		movement_speed = speed_medium_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		--dying_explosion = "small-explosion",
		dying_sound = robot_dying_sounds( 0.6 ),
		working_sound = robot_working_sounds( 0.8, "3" ),
		run_animation = bot_run_animation( scale_medium_bot, faction.color, "tesla" )
	  },
	  
	  {
		type = "unit",
		name = "medium-laser-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 260,
		order = "l-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 5,
			percent = 20
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 10
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 10,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 10,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 10,
		  },
		},
		collision_box = {{-0.3, -0.3}, {0.3, 0.3}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = laser_attack_parameters(
		{
		  range = 14,
		  min_attack_distance = 13,
		  projectile_creation_distance = projectile_creation_distance_small_bot + 0.5,
		  warmup = 1,
		  cooldown = 30,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.2 * 6,
		  sound = laser_shots(0.6),
		  animation = bot_attack_animation( scale_medium_bot, faction.color, "laser" )
		}),
		vision_distance = 38,
		movement_speed = speed_medium_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = robot_dying_sounds( 0.6 ),
		working_sound = robot_working_sounds( 0.8, "3" ),
		run_animation = bot_run_animation( scale_medium_bot, faction.color, "laser" )
	  },
	-------------------------------------------------------------------------------------------------------------------------------------------
	{
		type = "unit",
		name = "large-pistol-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 400,
		order = "p-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 20
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 20,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 20,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 20,
		  },
		},
		collision_box = {{-0.4, -0.4}, {0.4, 0.4}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = bullet_attack_parameters(
		{
		  range = 10,
		  min_attack_distance = 9,
		  projectile_creation_distance = projectile_creation_distance_large_bot,
		  warmup = 1,
		  cooldown = 15,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 12,
		  damage_type = "physical",
		  sound = light_gunshots(0.8),
		  animation = bot_attack_animation( scale_large_bot, faction.color, "pistol" )
		}),
		vision_distance = 35,
		movement_speed = speed_large_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = large_robot_dying_sounds( 0.8 ),
		working_sound = robot_working_sounds( 0.9, "4" ),
		run_animation = bot_run_animation( scale_large_bot, faction.color, "pistol" )
	  },	  
	  
	  {
		type = "unit",
		name = "large-machine-gun-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 460,
		order = "m-g-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 20
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "physical",
			decrease = 4,
			percent = 30
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 20,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 20,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 20,
		  },
		},
		collision_box = {{-0.4, -0.4}, {0.4, 0.4}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = bullet_attack_parameters(
		{
		  range = 12,
		  min_attack_distance = 11,
		  projectile_creation_distance = projectile_creation_distance_large_bot,
		  warmup = 1,
		  cooldown = 3,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 4,
		  damage_type = "physical",
		  sound = light_gunshots(0.55),
		  animation = bot_attack_animation( scale_large_bot, faction.color, "machine-gun" )
		}),
		vision_distance = 36,
		movement_speed = speed_large_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = large_robot_dying_sounds( 0.8 ),
		working_sound = robot_working_sounds( 0.9, "4" ),
		run_animation = bot_run_animation( scale_large_bot, faction.color, "machine-gun" )
	  },

	  {
		type = "unit",
		name = "large-shotgun-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 500,
		order = "s-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 20
		  },	  
		  {
			type = "impact",
			decrease = 8,
			percent = 30
		  },
		  {
			type = "physical",
			decrease = 4,
			percent = 20
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 20,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 20,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 20,
		  },
		},
		collision_box = {{-0.4, -0.4}, {0.4, 0.4}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = pellet_attack_parameters(
		{
		  range = 11,
		  min_attack_distance = 10,
		  projectile_creation_distance = projectile_creation_distance_large_bot,
		  warmup = 1,
		  cooldown = 30,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.2 * 6,
		  repeat_count = 12,
		  sound = shotgun_shots(0.75),
		  animation = bot_attack_animation( scale_large_bot, faction.color, "shotgun" )
		}),
		vision_distance = 35,
		movement_speed = speed_large_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = large_robot_dying_sounds( 0.8 ),
		working_sound = robot_working_sounds( 0.9, "4" ),
		run_animation = bot_run_animation( scale_large_bot, faction.color, "shotgun" )
	  },
	  
	  {
		type = "unit",
		name = "large-flame-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 540,
		order = "f-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 20
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 20,
		  },
		  {
			type = "fire",
			decrease = 4,
			percent = 85,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 20,
		  },
		},
		collision_box = {{-0.3, -0.3}, {0.3, 0.3}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = flame_attack_parameters(
		{
		  range = 12,
		  min_attack_distance = 11,
		  projectile_creation_distance = projectile_creation_distance_large_bot,
		  warmup = 1,
		  cooldown = 2,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.14 * 4,
		  sound_volume = 0.8,
		  animation = bot_attack_animation( scale_large_bot, faction.color, "flame" )
		}),
		vision_distance = 37,
		movement_speed = speed_large_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = large_robot_dying_sounds( 0.8 ),
		working_sound = robot_working_sounds( 0.9, "4" ),
		run_animation = bot_run_animation( scale_large_bot, faction.color, "flame" )
	  },	
	  
	  {
		type = "unit",
		name = "large-rocket-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 600,
		order = "r-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 20
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "explosion",
			decrease = 15,
			percent = 30,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 20,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 20,
		  },
		},
		collision_box = {{-0.3, -0.3}, {0.3, 0.3}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = rocket_attack_parameters(
		{
		  range = 14,
		  min_attack_distance = 13,
		  projectile_creation_distance = projectile_creation_distance_large_bot,
		  warmup = 10,
		  cooldown = 90,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.005 * 75,
		  sound = rocket_shots(0.75),
		  animation = bot_attack_animation( scale_large_bot, faction.color, "rocket" )
		}),
		vision_distance = 38,
		movement_speed = speed_large_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = large_robot_dying_sounds( 0.8 ),
		working_sound = robot_working_sounds( 0.9, "4" ),
		run_animation = bot_run_animation( scale_large_bot, faction.color, "rocket" )
	  },
	  
	  {
		type = "unit",
		name = "large-grenade-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 640,
		order = "g -b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 20
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "explosion",
			decrease = 15,
			percent = 30,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 20,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 20,
		  },
		},
		collision_box = {{-0.3, -0.3}, {0.3, 0.3}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = grenade_attack_parameters(
		{
		  range = 14,
		  min_attack_distance = 13,
		  projectile_creation_distance = projectile_creation_distance_large_bot,
		  warmup = 15,
		  cooldown = 90,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.0285 * 35,
		  sound = grenade_shots(0.8),
		  animation = bot_attack_animation( scale_large_bot, faction.color, "grenade" )
		}),
		vision_distance = 38,
		movement_speed = speed_large_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = large_robot_dying_sounds( 0.8 ),
		working_sound = robot_working_sounds( 0.9, "4" ),
		run_animation = bot_run_animation( scale_large_bot, faction.color, "grenade" )
	  },		  
	  
	  {
		type = "unit",
		name = "large-tesla-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 250,
		order = "t-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 20
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 20,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 20,
		  },		  
		  {
			type = "electric",
			decrease = 4,
			percent = 25,
		  },
		},
		collision_box = {{-0.4, -0.4}, {0.4, 0.4}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = beam_attack_parameters(
		{
		  range = 13,
		  min_attack_distance = 12,
		  projectile_creation_distance = projectile_creation_distance_small_bot,
		  warmup = 0,
		  cooldown = 20,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.1 * 20,
		  sound = beam_shots(1),
		  max_length = 14,
		  duration = 20,
		  animation = bot_attack_animation( scale_large_bot, faction.color, "tesla" )
		}),
		vision_distance = 38,
		movement_speed = speed_large_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = large_robot_dying_sounds( 0.8 ),
		working_sound = robot_working_sounds( 0.9, "4" ),
		run_animation = bot_run_animation( scale_large_bot, faction.color, "tesla" )
	  },
	  
	  {
		type = "unit",
		name = "large-laser-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 680,
		order = "l-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 10,
			percent = 40
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 20
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 20,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 20,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 20,
		  },
		},
		collision_box = {{-0.3, -0.3}, {0.3, 0.3}},
		selection_box = {{-0.7, -1.5}, {0.7, 0.3}},
		attack_parameters = laser_attack_parameters(
		{
		  range = 15,
		  min_attack_distance = 14,
		  projectile_creation_distance = projectile_creation_distance_small_bot + 0.5,
		  warmup = 1,
		  cooldown = 15,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.2 * 12,
		  sound = laser_shots(0.8),
		  animation = bot_attack_animation( scale_large_bot, faction.color, "laser" )
		}),
		vision_distance = 40,
		movement_speed = speed_large_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "medium-remnants",
		dying_sound = large_robot_dying_sounds( 0.8 ),
		working_sound = robot_working_sounds( 0.9, "4" ),
		run_animation = bot_run_animation( scale_large_bot, faction.color, "laser" )
	  },
	  -----------------------------------------------------------------------------------------------------------------------------------------
	
	{
		type = "unit",
		name = "giant-pistol-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 1000,
		order = "p-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 30
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 30,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 30,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 30,
		  },
		},
		collision_box = {{-0.5, -0.5}, {0.5, 0.5}},
		selection_box = {{-0.85, -1.75}, {0.85, 0.45}},
		attack_parameters = bullet_attack_parameters(
		{
		  range = 11,
		  min_attack_distance = 10,
		  projectile_creation_distance = projectile_creation_distance_giant_bot,
		  warmup = 1,
		  cooldown = 8,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 24,
		  damage_type = "physical",
		  sound = light_gunshots(0.75),
		  animation = bot_attack_animation( scale_giant_bot, faction.color, "pistol" )
		}),
		vision_distance = 36,
		movement_speed = speed_giant_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "big-remnants",
		dying_sound = giant_robot_dying_sounds( 1 ),
		working_sound = robot_working_sounds( 1, "5" ),
		run_animation = bot_run_animation( scale_giant_bot, faction.color, "pistol" )
	  },	  
	  
	  {
		type = "unit",
		name = "giant-machine-gun-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 1100,
		order = "m-g-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 30
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "physical",
			decrease = 6,
			percent = 40
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 30,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 30,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 30,
		  },
		},
		collision_box = {{-0.5, -0.5}, {0.5, 0.5}},
		selection_box = {{-0.85, -1.75}, {0.85, 0.45}},
		attack_parameters = bullet_attack_parameters(
		{
		  range = 13,
		  min_attack_distance = 12,
		  projectile_creation_distance = projectile_creation_distance_giant_bot,
		  warmup = 1,
		  cooldown = 2,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 6,
		  damage_type = "physical",
		  sound = light_gunshots(0.75),
		  animation = bot_attack_animation( scale_giant_bot, faction.color, "machine-gun" )
		}),
		vision_distance = 37,
		movement_speed = speed_giant_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "big-remnants",
		dying_sound = giant_robot_dying_sounds( 1 ),
		working_sound = robot_working_sounds( 1, "5" ),
		run_animation = bot_run_animation( scale_giant_bot, faction.color, "machine-gun" )
	  },

	  {
		type = "unit",
		name = "giant-shotgun-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 1200,
		order = "s-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 30
		  },	  
		  {
			type = "impact",
			decrease = 10,
			percent = 30
		  },
		  {
			type = "physical",
			decrease = 6,
			percent = 30
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 30,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 30,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 30,
		  },
		},
		collision_box = {{-0.5, -0.5}, {0.5, 0.5}},
		selection_box = {{-0.85, -1.75}, {0.85, 0.45}},
		attack_parameters = pellet_attack_parameters(
		{
		  range = 12,
		  min_attack_distance = 11,
		  projectile_creation_distance = projectile_creation_distance_giant_bot,
		  warmup = 1,
		  cooldown = 20,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.2 * 10,
		  repeat_count = 14,
		  sound = shotgun_shots(0.8),
		  animation = bot_attack_animation( scale_giant_bot, faction.color, "shotgun" )
		}),
		vision_distance = 38,
		movement_speed = speed_giant_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "big-remnants",
		dying_sound = giant_robot_dying_sounds( 1 ),
		working_sound = robot_working_sounds( 1, "5" ),
		run_animation = bot_run_animation( scale_giant_bot, faction.color, "shotgun" )
	  },
	  
	  {
		type = "unit",
		name = "giant-flame-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 1400,
		order = "f-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 30
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 30,
		  },
		  {
			type = "fire",
			decrease = 6,
			percent = 90,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 30,
		  },
		},
		collision_box = {{-0.5, -0.5}, {0.5, 0.5}},
		selection_box = {{-0.85, -1.75}, {0.85, 0.45}},
		attack_parameters = flame_attack_parameters(
		{
		  range = 13,
		  min_attack_distance = 12,
		  projectile_creation_distance = projectile_creation_distance_giant_bot,
		  warmup = 1,
		  cooldown = 2,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.14 * 8,
		  sound_volume = 0.8,
		  animation = bot_attack_animation( scale_giant_bot, faction.color, "flame" )
		}),
		vision_distance = 38,
		movement_speed = speed_giant_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "big-remnants",
		dying_sound = giant_robot_dying_sounds( 1 ),
		working_sound = robot_working_sounds( 1, "5" ),
		run_animation = bot_run_animation( scale_giant_bot, faction.color, "flame" )
	  },	
	  
	  {
		type = "unit",
		name = "giant-rocket-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 1600,
		order = "r-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 30
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "explosion",
			decrease = 20,
			percent = 40,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 30,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 30,
		  },
		},
		collision_box = {{-0.5, -0.5}, {0.5, 0.5}},
		selection_box = {{-0.85, -1.75}, {0.85, 0.45}},
		attack_parameters = rocket_attack_parameters(
		{
		  range = 15,
		  min_attack_distance = 14,
		  projectile_creation_distance = projectile_creation_distance_giant_bot,
		  warmup = 10,
		  cooldown = 60,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.005 * 200,
		  sound = rocket_shots(0.8),
		  animation = bot_attack_animation( scale_giant_bot, faction.color, "rocket" )
		}),
		vision_distance = 38,
		movement_speed = speed_giant_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "big-remnants",
		dying_sound = giant_robot_dying_sounds( 1 ),
		working_sound = robot_working_sounds( 1, "5" ),
		run_animation = bot_run_animation( scale_giant_bot, faction.color, "rocket" )
	  },
	  
	  {
		type = "unit",
		name = "giant-grenade-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 1800,
		order = "g -b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 30
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "explosion",
			decrease = 20,
			percent = 40,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 30,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 30,
		  },
		},
		collision_box = {{-0.5, -0.5}, {0.5, 0.5}},
		selection_box = {{-0.85, -1.75}, {0.85, 0.45}},
		attack_parameters = grenade_attack_parameters(
		{
		  range = 15,
		  min_attack_distance = 14,
		  projectile_creation_distance = projectile_creation_distance_giant_bot,
		  warmup = 10,
		  cooldown = 60,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.0285 * 65,
		  sound = grenade_shots(0.8),
		  animation = bot_attack_animation( scale_giant_bot, faction.color, "grenade" )
		}),
		vision_distance = 38,
		movement_speed = speed_giant_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "big-remnants",
		dying_sound = giant_robot_dying_sounds( 1 ),
		working_sound = robot_working_sounds( 1, "5" ),
		run_animation = bot_run_animation( scale_giant_bot, faction.color, "grenade" )
	  },		  
	  
	  {
		type = "unit",
		name = "giant-tesla-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 2000,
		order = "t-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 0,
			percent = 30
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 30,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 30,
		  },		  
		  {
			type = "electric",
			decrease = 6,
			percent = 40,
		  },
		},
		collision_box = {{-0.5, -0.5}, {0.5, 0.5}},
		selection_box = {{-0.85, -1.75}, {0.85, 0.45}},
		attack_parameters = beam_attack_parameters(
		{
		  range = 14,
		  min_attack_distance = 13,
		  projectile_creation_distance = projectile_creation_distance_small_bot,
		  warmup = 0,
		  cooldown = 20,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.1 * 40,
		  sound = beam_shots(1),
		  max_length = 15,
		  duration = 20,
		  animation = bot_attack_animation( scale_giant_bot, faction.color, "tesla" )
		}),
		vision_distance = 39,
		movement_speed = speed_giant_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "big-remnants",
		--dying_explosion = "small-explosion",
		dying_sound = giant_robot_dying_sounds( 1 ),
		working_sound = robot_working_sounds( 1, "5" ),
		run_animation = bot_run_animation( scale_giant_bot, faction.color, "tesla" )
	  },
	  
	  {
		type = "unit",
		name = "giant-laser-bot-"..faction.id,
		icon = "__base__/graphics/icons/small-biter.png",
		flags = {"placeable-player", "placeable-enemy", "placeable-off-grid",},
		max_health = 2000,
		order = "l-b",
		subgroup="enemies",
		map_color = faction.color,
		healing_per_tick = 0,
		resistances = 
		{
		  {
			type = "laser",
			decrease = 12,
			percent = 50
		  },	  
		  {
			type = "impact",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "physical",
			decrease = 0,
			percent = 30
		  },
		  {
			type = "explosion",
			decrease = 0,
			percent = 30,
		  },
		  {
			type = "fire",
			decrease = 0,
			percent = 30,
		  },		  
		  {
			type = "electric",
			decrease = 0,
			percent = 30,
		  },
		},
		collision_box = {{-0.5, -0.5}, {0.5, 0.5}},
		selection_box = {{-0.85, -1.75}, {0.85, 0.45}},
		attack_parameters = laser_attack_parameters(
		{
		  range = 16,
		  min_attack_distance = 15,
		  projectile_creation_distance = projectile_creation_distance_small_bot + 0.5,
		  warmup = 1,
		  cooldown = 12,
		  damage_modifier = faction.damage_modifier,
		  damage_amount = 0.2 * 24,
		  sound = laser_shots(0.8),
		  animation = bot_attack_animation( scale_giant_bot, faction.color, "laser" )
		}),
		vision_distance = 41,
		movement_speed = speed_giant_bot,
		distance_per_frame = 0.1,
		pollution_to_join_attack = 0,
		distraction_cooldown = 300,
		min_pursue_time = 10 * 60,
		max_pursue_distance = 50,
		corpse = "big-remnants",
		dying_sound = giant_robot_dying_sounds( 1 ),
		working_sound = robot_working_sounds( 1, "5" ),
		run_animation = bot_run_animation( scale_giant_bot, faction.color, "laser" )
	  },
	
	})
	
end
